<?php

declare(strict_types=1);

namespace App\Controller\PunchCard\User;

use App\Controller\BaseController;
use App\JsonRpc\PunchCardSystemExternalServiceInterface;
use App\JsonRpc\UserExternalServiceInterface;
use Hyperf\Di\Annotation\Inject;
use Hyperf\HttpServer\Annotation\Controller;
use Hyperf\HttpServer\Annotation\GetMapping;
use Hyperf\HttpServer\Annotation\PostMapping;

#[Controller(prefix: "kq")]
class UserController extends BaseController
{
    /**
     * 用户中心对外RPC服务
     *
     * @var UserExternalServiceInterface
     */
    #[Inject]
    protected UserExternalServiceInterface $userExternalService;

    /**
     * 考勤系统设置对外RPC服务
     *
     * @var PunchCardSystemExternalServiceInterface
     */
    #[Inject]
    protected PunchCardSystemExternalServiceInterface $punchCardSystemExternalService;

    /**
     * 获取个人资料
     *
     * @return array
     */
    #[GetMapping(path: "user/information")]
    public function information() : array
    {
        $openid = $this->request->input('openid', '');
        return $this->getServiceResult($this->userExternalService->getUserInfo($openid, [
            'user_name',
            'user_phone',
        ]));
    }

    /**
     * 保存个人资料
     *
     * @return void
     */
    #[PostMapping(path: "user/save_information")]
    public function saveInformation() : void
    {
        $phone = $this->request->input('phone', '');
        // TODO 逻辑完善
    }

    /**
     * 保存问题反馈
     *
     * @return array
     */
    #[PostMapping(path: "user/save_feedback")]
    public function saveFeedback() : array
    {
        return $this->getServiceResult($this->punchCardSystemExternalService->saveFeedback($this->request));
    }
}
